/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgCpg

Description
    NSRDS-AICHE function number 107

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgCpg_H
#define NSRDSfuncgCpg_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgCpg Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgCpg
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 107 coefficients
        scalar a_, b_, c_, d_, e_;
        scalar cpg[50];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgCpg");


    // Constructors

        //- Construct from components
        NSRDSfuncgCpg(scalar a, scalar b, scalar c, scalar d, scalar e)
        :
            a_(a),
            b_(b),
            c_(c),
            d_(d),
            e_(e)
        {}

        //- Construct from Istream
        NSRDSfuncgCpg(Istream& is)
        :
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is)),
            e_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgCpg() {
        // cpg starts from 50 K, ends at 4950 K with temperature interval 100 K     
            cpg[0] = 9.52081e+02;
            cpg[1] = 9.52081e+02;
            cpg[2] = 1.45932e+03;
            cpg[3] = 1.89346e+03;
            cpg[4] = 2.32575e+03;
            cpg[5] = 2.70968e+03;
            cpg[6] = 3.03787e+03;
            cpg[7] = 3.31918e+03;
            cpg[8] = 3.50745e+03;
            cpg[9] = 3.72784e+03;
            cpg[10] = 3.87330e+03;
            cpg[11] = 4.02355e+03;
            cpg[12] = 4.17343e+03;
            cpg[13] = 4.24394e+03;
            cpg[14] = 4.35875e+03;
            cpg[15] = 4.35875e+03;
            cpg[16] = 4.35875e+03;
            cpg[17] = 4.35875e+03;
            cpg[18] = 4.35875e+03;
            cpg[19] = 4.35875e+03;
            cpg[20] = 4.35875e+03;
            cpg[21] = 4.35875e+03;
            cpg[22] = 4.35875e+03;
            cpg[23] = 4.35875e+03;
            cpg[24] = 4.35875e+03;
            cpg[25] = 4.35875e+03;
            cpg[26] = 4.35875e+03;
            cpg[27] = 4.35875e+03;
            cpg[28] = 4.35875e+03;
            cpg[29] = 4.35875e+03;
            cpg[30] = 4.35875e+03;
            cpg[31] = 4.35875e+03;
            cpg[32] = 4.35875e+03;
            cpg[33] = 4.35875e+03;
            cpg[34] = 4.35875e+03;
            cpg[35] = 4.35875e+03;
            cpg[36] = 4.35875e+03;
            cpg[37] = 4.35875e+03;
            cpg[38] = 4.35875e+03;
            cpg[39] = 4.35875e+03;
            cpg[40] = 4.35875e+03;
            cpg[41] = 4.35875e+03;
            cpg[42] = 4.35875e+03;
            cpg[43] = 4.35875e+03;
            cpg[44] = 4.35875e+03;
            cpg[45] = 4.35875e+03;
            cpg[46] = 4.35875e+03;
            cpg[47] = 4.35875e+03;
            cpg[48] = 4.35875e+03;
            cpg[49] = 4.35875e+03;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar cpg_ = 0.0;
      
	    for(int i=0; i<49; i++){
		   if(T>=100*i+50 && T<100*(i+1)+50){
		   	cpg_ = cpg[i]+(T-100*i-50)*(cpg[i+1]-cpg[i])/100;
		   	break;
			}
		   }
	    return cpg_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_ << token::SPACE
                << e_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgCpg& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
