/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgHl

Description
    NSRDS function number 106

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgHl_H
#define NSRDSfuncgHl_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgHl Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgHl
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 106 coefficients
        scalar Tc_, a_, b_, c_, d_, e_;
        scalar hl[51];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgHl");


    // Constructors

        //- Construct from components
        NSRDSfuncgHl(scalar Tc, scalar a, scalar b, scalar c, scalar d, scalar e)
        :
            Tc_(Tc),
            a_(a),
            b_(b),
            c_(c),
            d_(d),
            e_(e)
        {}

        //- Construct from Istream
        NSRDSfuncgHl(Istream& is)
        :
            Tc_(readScalar(is)),
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is)),
            e_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgHl() {
            hl[0] = 4.91500e+05;
            hl[1] = 4.33200e+05;
            hl[2] = 3.74900e+05;
            hl[3] = 3.16600e+05;
            hl[4] = 2.27300e+05;
            hl[5] = 1.10000e+05;
            hl[6] = 0.00000e+00;
            hl[7] = 0.00000e+00;
            hl[8] = 0.00000e+00;
            hl[9] = 0.00000e+00;
            hl[10] = 0.00000e+00;
            hl[11] = 0.00000e+00;
            hl[12] = 0.00000e+00;
            hl[13] = 0.00000e+00;
            hl[14] = 0.00000e+00;
            hl[15] = 0.00000e+00;
            hl[16] = 0.00000e+00;
            hl[17] = 0.00000e+00;
            hl[18] = 0.00000e+00;
            hl[19] = 0.00000e+00;
            hl[20] = 0.00000e+00;
            hl[21] = 0.00000e+00;
            hl[22] = 0.00000e+00;
            hl[23] = 0.00000e+00;
            hl[24] = 0.00000e+00;
            hl[25] = 0.00000e+00;
            hl[26] = 0.00000e+00;
            hl[27] = 0.00000e+00;
            hl[28] = 0.00000e+00;
            hl[29] = 0.00000e+00;
            hl[30] = 0.00000e+00;
            hl[31] = 0.00000e+00;
            hl[32] = 0.00000e+00;
            hl[33] = 0.00000e+00;
            hl[34] = 0.00000e+00;
            hl[35] = 0.00000e+00;
            hl[36] = 0.00000e+00;
            hl[37] = 0.00000e+00;
            hl[38] = 0.00000e+00;
            hl[39] = 0.00000e+00;
            hl[40] = 0.00000e+00;
            hl[41] = 0.00000e+00;
            hl[42] = 0.00000e+00;
            hl[43] = 0.00000e+00;
            hl[44] = 0.00000e+00;
            hl[45] = 0.00000e+00;
            hl[46] = 0.00000e+00;
            hl[47] = 0.00000e+00;
            hl[48] = 0.00000e+00;
            hl[49] = 0.00000e+00;
            hl[50] = 0.00000e+00;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar hl_ = 0.0;
      
	    for(int i=0; i<50; i++){
		   if(T>=100*i && T<100*(i+1)){
		   	hl_ = hl[i]+(T-100*i)*(hl[i+1]-hl[i])/100;
		   	break;
			}
		   }
	    return hl_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << Tc_ << token::SPACE
                << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_ << token::SPACE
                << e_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgHl& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
